@@ -33,10 +33,16 @@ def run(datadir):
 
     pygtk.require('2.0')
 
+    from gettext import gettext as _
     from gnome_lirc_properties import ui
-    from gtk import glade
+    from gtk import gdk, glade
 
-    import os.path
+    import gobject, os.path
+
+    gobject.threads_init()
+    gobject.set_application_name(_('Infrared Remote Control Properties'))
+
+    gdk.threads_init()
 
     ui_filename = os.path.join(datadir, 'gnome-lirc-properties.glade')
     return ui.RemoteControlProperties(glade.XML(ui_filename)).run()
