@@ -22,7 +22,7 @@ The dialog for customizing remote control settings.
 import dbus, logging, gobject, gtk
 
 from gettext                         import gettext as _
-from gnome_lirc_properties           import config, lirc, model, upload
+from gnome_lirc_properties           import backend, config, lirc, model, net
 from gnome_lirc_properties.ui.common import show_message
 from StringIO                        import StringIO
 from time                            import time
@@ -82,6 +82,9 @@ class CustomConfiguration(object):
         self.__setup_basics()
         self.__setup_keys()
 
+        # apply "secondary" child property: for some reason libglade ignores it
+        self.__dialog.action_area.set_child_secondary(self.__button_upload, True)
+
     # pylint: disable-msg=W0201
     def __setup_basics(self):
         '''
@@ -296,11 +299,10 @@ class CustomConfiguration(object):
             self.__stop_learning()
 
         try:
-            bus = dbus.SystemBus()
-
-            mechanism = bus.get_object('org.gnome.LircProperties.Mechanism', '/')
-            driver = mechanism.LearnKeyCode(driver, device, configuration, [mapping.key])
-            driver = bus.get_object(mechanism.requested_bus_name, driver)
+            bus     = backend.get_service_bus()
+            service = backend.get_service(bus)
+            driver  = service.LearnKeyCode(driver, device, configuration, [mapping.key])
+            driver  = bus.get_object(service.requested_bus_name, driver)
 
             self.__learning_driver = driver
 
@@ -357,11 +359,11 @@ class CustomConfiguration(object):
         upload_uri = (base_uri + 'Special:Upload&wpUpload=Upload+file')
 
         # TODO: Use the URIs provided to configure:
-        # login_uri = config.URI_LOGIN_UPLOADS
+        # login_uri = config.URI_UPLOADS_LOGIN
         # upload_uri = config.URI_UPLOADS
 
-        uploader = upload.HttpUploader(upload_uri, login_uri,
-                                       'Murrayc', 'enterpasswordhere')
+        uploader = net.HttpUploader(upload_uri, login_uri,
+                                    'Murrayc', 'enterpasswordhere')
 
         # TODO: For mediawiki, the name should always
         # start with a capital letter, and have no spaces.
@@ -389,7 +391,7 @@ class CustomConfiguration(object):
         Handle the "Detect" button's "clicked" signal.
         '''
 
-        mechanism, driver = None, None
+        service, driver = None, None
 
         def report_failure(message):
             '''
@@ -399,8 +401,8 @@ class CustomConfiguration(object):
             self.__progressbar_detect_basics.hide()
             show_message(self.__dialog, _('Remote Configuration Failed'), message)
 
-            if mechanism:
-                mechanism.ManageLircDaemon('start')
+            if service:
+                service.ManageLircDaemon('start')
 
         def report_success(result, sender=None):
             '''
@@ -418,8 +420,8 @@ class CustomConfiguration(object):
             self.__remote.properties = remote.properties
             self.__update_basics_model(self.__remote.properties)
 
-            if mechanism:
-                mechanism.ManageLircDaemon('start')
+            if service:
+                service.ManageLircDaemon('start')
 
         def report_progress(sender=None):
             '''
@@ -442,12 +444,12 @@ class CustomConfiguration(object):
             driver.Proceed()
 
         try:
-            bus = dbus.SystemBus()
+            bus     = backend.get_service_bus()
+            service = backend.get_service(bus)
 
-            mechanism = bus.get_object('org.gnome.LircProperties.Mechanism', '/')
-            driver = mechanism.DetectParameters(self.__receiver.lirc_driver or '',
-                                                self.__device or '')
-            driver = bus.get_object(mechanism.requested_bus_name, driver)
+            driver = service.DetectParameters(self.__receiver.lirc_driver or '',
+                                              self.__device or '')
+            driver = bus.get_object(service.requested_bus_name, driver)
 
             driver.connect_to_signal('RequestAction',  request_action)
             driver.connect_to_signal('ReportProgress', report_progress)
@@ -455,7 +457,7 @@ class CustomConfiguration(object):
             driver.connect_to_signal('ReportFailure',  report_failure)
 
             # TODO: Stop the key-listener, when we know that lircd is disabled.
-            mechanism.ManageLircDaemon('stop')
+            service.ManageLircDaemon('stop')
             driver.Execute()
 
             self.__progressbar_detect_basics.show()
@@ -616,10 +618,9 @@ class CustomConfiguration(object):
 
         if gtk.RESPONSE_OK == response:
             try:
-                bus = dbus.SystemBus()
-                mechanism = bus.get_object('org.gnome.LircProperties.Mechanism', '/')
-                self.__remote.update_configuration(mechanism)
-                mechanism.ManageLircDaemon('restart')
+                service = backend.get_service()
+                self.__remote.update_configuration(service)
+                service.ManageLircDaemon('restart')
 
             except dbus.DBusException, ex:
                 show_message(self.__dialog,
@@ -628,6 +629,9 @@ class CustomConfiguration(object):
 
                 dialog.stop_emission('response')
 
+        elif response > 0:
+            dialog.stop_emission('response')
+
     def run(self, receiver, device, remote):
         '''
         Show the dialog and return when the window is hidden.
